@@ -1149,7 +1149,8 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
                  pit != prefixList->end();
                  ++pit)
             {
-            if((*pit).compare(installprefix, cs) != 0 || installdir.isEmpty())
+            // "exe" never has a custom install path, and the check triggers a false positive due to the libexecdir patch
+            if((*pit).compare(installprefix, cs) != 0 || installdir.isEmpty() || !strcmp("exe", type))
             {
                     for (QStringList::ConstIterator it = dirs.constBegin();
                          it != dirs.constEnd(); ++it)
@@ -1163,6 +1164,11 @@ QStringList KStandardDirs::KStandardDirsPrivate::resourceDirs(const char* type,
                         if ((local || testdir.exists()) && !candidates.contains(path, cs))
                             candidates.append(path);
                     }
+                    // special-case "config" (forward porting Chris Cheney's
+                    // hack) - we want /etc/kde after the local config paths
+                    // and before the ones in /usr (including kde-profile)
+                    if (local && !strcmp("config", type))
+                       candidates.append(QLatin1String("/etc/kde/"));
                     local = false;
                 }
             else
@@ -1859,7 +1865,7 @@ void KStandardDirs::addKDEDefaults()
         addResourceType(types_string + types_indices[index], 0, types_string + types_indices[index+1], true);
         index+=2;
     }
-    addResourceType("exe", "lib", "kde4/libexec", true );
+    addResourceType("exe", 0, "libexec/kde4", true );
 
     addResourceDir("home", QDir::homePath(), false);
 
